==> randomForestSRC_1.2.tar.gz: randomForestSRC/src/node.h <==
////**********************************************************************
////**********************************************************************
////
////  RANDOM FORESTS FOR SURVIVAL, REGRESSION, AND CLASSIFICATION (RF-SRC)
////  Version 1.2
////
////  Copyright 2012, University of Miami
////
////  This program is free software; you can redistribute it and/or
////  modify it under the terms of the GNU General Public License
////  as published by the Free Software Foundation; either version 2
////  of the License, or (at your option) any later version.
////
////  This program is distributed in the hope that it will be useful,
////  but WITHOUT ANY WARRANTY; without even the implied warranty of
////  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
////  GNU General Public License for more details.
////
////  You should have received a copy of the GNU General Public
////  License along with this program; if not, write to the Free
////  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
////  Boston, MA  02110-1301, USA.
////
////  ----------------------------------------------------------------
////  Project Partially Funded By: 
////  ----------------------------------------------------------------
////  Dr. Ishwaran's work was funded in part by DMS grant 1148991 from the
////  National Science Foundation and grant R01 CA163739 from the National
////  Cancer Institute.
////
////  Dr. Kogalur's work was funded in part by grant R01 CA163739 from the 
////  National Cancer Institute.
////  ----------------------------------------------------------------
////  Written by:
////  ----------------------------------------------------------------
////    Hemant Ishwaran, Ph.D.
////    Director of Statistical Methodology
////    Professor, Division of Biostatistics
////    Clinical Research Building, Room 1058
////    1120 NW 14th Street
////    University of Miami, Miami FL 33136
////
////    email:  hemant.ishwaran@gmail.com
////    URL:    http://web.ccs.miami.edu/~hishwaran
////    --------------------------------------------------------------
////    Udaya B. Kogalur, Ph.D.
////    Adjunct Staff
////    Dept of Quantitative Health Sciences
////    Cleveland Clinic Foundation
////    
////    Kogalur & Company, Inc.
////    5425 Nestleway Drive, Suite L1
////    Clemmons, NC 27012
////
////    email:  commerce@kogalur.com
////    URL:    http://www.kogalur.com
////    --------------------------------------------------------------
////
////**********************************************************************
////**********************************************************************


#ifndef NODE_H
#define NODE_H
typedef struct node Node;
struct node {
  struct node *parent;
  unsigned int xSize;
  char splitFlag;
  double predictedOutcome;
  unsigned int splitParameter;
  double splitValueCont;
  double splitStatistic;
  double variance;
  unsigned int splitValueFactSize;
  unsigned int *splitValueFactPtr;
  unsigned int leafCount;
  unsigned int depth;
  char pseudoTerminal;
  struct terminal *mate;
  struct node *left;
  struct node *right;
  char *permissibleSplit;
  unsigned int *splitDepth;
  unsigned int eTypeSize;
  unsigned int mTimeSize;
  unsigned int eTimeSize;
  unsigned int sTimeSize;
  unsigned int *atRiskCount;
  unsigned int **eventCount;
  unsigned int *eventTimeIndex;
  double **localRatio;
  double **localCSH;
  double **localCIF;
  double *localSurvival;
  double *localNelsonAalen;
  double **CSH;
  double **CIF;
  double *survival;
  double *nelsonAalen;
  double *mortality;
  unsigned int   rfCount;
  unsigned int  *rfSize;
  unsigned int **multiClassProb;
  unsigned int membrCount;
  unsigned int mvSignSize;
  unsigned int fmvSignSize;
  int *mvSign;
  int *fmvSign;
  unsigned int *lmvIndex;
  unsigned int  lmvIndexAllocSize;
  unsigned int  lmvIndexActualSize;
  unsigned int *flmvIndex;
  unsigned int  flmvIndexAllocSize;
  unsigned int  flmvIndexActualSize;
  unsigned int *lmrIndex;
  unsigned int  lmrIndexAllocSize;
  unsigned int  lmrIndexActualSize;
  unsigned int *flmrIndex;
  unsigned int  flmrIndexAllocSize;
  unsigned int  flmrIndexActualSize;
};
#endif

==> randomForestSRC_1.3.tar.gz: randomForestSRC/src/node.h <==
////**********************************************************************
////**********************************************************************
////
////  RANDOM FORESTS FOR SURVIVAL, REGRESSION, AND CLASSIFICATION (RF-SRC)
////  Version 1.3
////
////  Copyright 2012, University of Miami
////
////  This program is free software; you can redistribute it and/or
////  modify it under the terms of the GNU General Public License
////  as published by the Free Software Foundation; either version 2
////  of the License, or (at your option) any later version.
////
////  This program is distributed in the hope that it will be useful,
////  but WITHOUT ANY WARRANTY; without even the implied warranty of
////  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
////  GNU General Public License for more details.
////
////  You should have received a copy of the GNU General Public
////  License along with this program; if not, write to the Free
////  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
////  Boston, MA  02110-1301, USA.
////
////  ----------------------------------------------------------------
////  Project Partially Funded By: 
////  ----------------------------------------------------------------
////  Dr. Ishwaran's work was funded in part by DMS grant 1148991 from the
////  National Science Foundation and grant R01 CA163739 from the National
////  Cancer Institute.
////
////  Dr. Kogalur's work was funded in part by grant R01 CA163739 from the 
////  National Cancer Institute.
////  ----------------------------------------------------------------
////  Written by:
////  ----------------------------------------------------------------
////    Hemant Ishwaran, Ph.D.
////    Director of Statistical Methodology
////    Professor, Division of Biostatistics
////    Clinical Research Building, Room 1058
////    1120 NW 14th Street
////    University of Miami, Miami FL 33136
////
////    email:  hemant.ishwaran@gmail.com
////    URL:    http://web.ccs.miami.edu/~hishwaran
////    --------------------------------------------------------------
////    Udaya B. Kogalur, Ph.D.
////    Adjunct Staff
////    Dept of Quantitative Health Sciences
////    Cleveland Clinic Foundation
////    
////    Kogalur & Company, Inc.
////    5425 Nestleway Drive, Suite L1
////    Clemmons, NC 27012
////
////    email:  commerce@kogalur.com
////    URL:    http://www.kogalur.com
////    --------------------------------------------------------------
////
////**********************************************************************
////**********************************************************************


#ifndef NODE_H
#define NODE_H
typedef struct node Node;
struct node {
  struct node *parent;
  unsigned int xSize;
  char splitFlag;
  double predictedOutcome;
  unsigned int splitParameter;
  double splitValueCont;
  double splitStatistic;
  double variance;
  unsigned int splitValueFactSize;
  unsigned int *splitValueFactPtr;
  unsigned int nodeID;
  unsigned int orderedNodeID;
  unsigned int depth;
  char pseudoTerminal;
  struct terminal *mate;
  struct node *left;
  struct node *right;
  char *permissibleSplit;
  unsigned int *splitDepth;
  unsigned int eTypeSize;
  unsigned int mTimeSize;
  unsigned int eTimeSize;
  unsigned int sTimeSize;
  unsigned int *atRiskCount;
  unsigned int **eventCount;
  unsigned int *eventTimeIndex;
  double **localRatio;
  double **localCSH;
  double **localCIF;
  double *localSurvival;
  double *localNelsonAalen;
  double **CSH;
  double **CIF;
  double *survival;
  double *nelsonAalen;
  double *mortality;
  unsigned int   rfCount;
  unsigned int  *rfSize;
  unsigned int **multiClassProb;
  unsigned int membrCount;
  unsigned int mpIndexSize;
  unsigned int fmpIndexSize;
  int *mpSign;
  int *fmpSign;
  unsigned int *lmpIndex;
  unsigned int  lmpIndexAllocSize;
  unsigned int  lmpIndexActualSize;
  unsigned int *flmpIndex;
  unsigned int  flmpIndexAllocSize;
  unsigned int  flmpIndexActualSize;
  unsigned int *lmrIndex;
  unsigned int  lmrIndexAllocSize;
  unsigned int  lmrIndexActualSize;
  unsigned int *flmrIndex;
  unsigned int  flmrIndexAllocSize;
  unsigned int  flmrIndexActualSize;
};
#endif
